/**
  *  \file client/widgets/objcontrol.cc
  *  \brief Object type control widget
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/objcontrol.h"
#include "game/obj.h"
#include "game/global.h"

WObjectTypeControl::WObjectTypeControl(GObjectType& type)
    : UIFixedWidget(),
      type(type)
{ }

bool
WObjectTypeControl::handleEvent(const UIEvent& event, bool second_pass)
{
    if (event.type == ev_Key) {
        switch (event.key.code) {
         case SDLK_PAGEUP:
         case SDLK_UP:
         case vk_WheelUp:
         case '-':
            type.setCurrent(type.getPreviousWrap(type.getCurrent(), false));
            return true;
         case SDLK_PAGEDOWN:
         case SDLK_DOWN:
         case vk_WheelDown:
         case '+':
            type.setCurrent(type.getNextWrap(type.getCurrent(), false));
            return true;
         case ss_Ctrl + SDLK_PAGEUP:
         case ss_Ctrl + SDLK_UP:
            type.setCurrent(type.getPreviousWrap(type.getCurrent(), true));
            return true;
         case ss_Ctrl + SDLK_PAGEDOWN:
         case ss_Ctrl + SDLK_DOWN:
            type.setCurrent(type.getNextWrap(type.getCurrent(), true));
            return true;
         case SDLK_HOME:
            type.setCurrent(type.getNextNoWrap(0, false));
            return true;
         case SDLK_END:
            type.setCurrent(type.getPreviousNoWrap(0, false));
            return true;
         case ss_Ctrl + SDLK_HOME:
            type.setCurrent(type.getNextNoWrap(0, true));
            return true;
         case ss_Ctrl + SDLK_END:
            type.setCurrent(type.getPreviousNoWrap(0, true));
            return true;
         case '.': {
            GObject& g = type.getObject(type.getCurrent());
            g.setIsMarked(!g.isMarked());
            type.getUniverse()->doScreenUpdates();
            return true;
         }
        }
    }
    return UIFixedWidget::handleEvent(event, second_pass);
}

void
WObjectTypeControl::drawContent(GfxCanvas& /*can*/)
{ }
