/**
  *  \file game/reg.h
  *  \brief Functions for dealing with Registrations
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_REG_H
#define PCC_V2_GAME_REG_H

#include "cpluslib/types.h"
#include "cpluslib/string.h"

class Stream;
class Directory;

//! Registration info.
class GRegInfo {
    /// Key data.
    uint32_t fizz[51];

    /// Winplan's additional strings (user-settable).
    char wpstrings[2][50];

    /// Validity flag.
    bool valid;

    /// Unregistered key.
    static const uint32_t unreg_fizz[];

    string_t decode(int n) const;
    void initFromFizz(const uint32_t* data);
 public:
    GRegInfo();
    
    void initUnregistered();
    void initUnowned();
    void initFromDirectory(Directory& dir, bool verbose);

    string_t getRegStr1() const;
    string_t getRegStr2() const;
    string_t getRegStr3() const;
    string_t getRegStr4() const;
    bool     isRegistered() const;
    bool     isValid() const;

    const uint32_t* getKey() const;

    void setRegStr3(const string_t& str);
    void setRegStr4(const string_t& str);

    void parseFizz(Stream& s);
    void parseKey(Stream& s);
};

// Globals
GRegInfo& getRegInfo();
bool      allowRegistered(int player);

extern const struct ModuleInitializer mod_reg[];

// Inlines

/** Check whether this registration is valid, i.e. was loaded from a file.
    Note that even if this returns false, the GRegInfo is usable and will
    contain an unregistered key.
    \retval true Files were loaded
    \retval false No files found or not loaded */
inline bool
GRegInfo::isValid() const
{
    return valid;
}

/** Get registration key in encoded form. This is used for turn files. */
inline const uint32_t*
GRegInfo::getKey() const
{
    return fizz;
}

#endif
